@@ -18,9 +18,19 @@ class ParentsTypesExporter(object):
     def __call__(self):
         """
         """
-        fathers_type_list = []
+        parents_type_list = []
         for item in self.context.aq_chain:
+            if item == self.context:
+                # skip current context
+                continue
             if ISiteRoot.providedBy(item):
                 break
-            fathers_type_list.append(item.portal_type)
-        return {"fathers_type_list": fathers_type_list}
+            parents_type_list.append(item.portal_type)
+        try:
+            parent_uid = self.context.aq_parent.UID()
+        except AttributeError:
+            parent_uid = ""
+        return {
+            "parents_type_list": parents_type_list,
+            "parent_uid": parent_uid,
+        }
