@@ -12,6 +12,7 @@ from zope.component import subscribers
 import base64
 import json
 import logging
+import six
 
 logger = logging.getLogger(__name__)
 
@@ -27,7 +28,6 @@ def _clean_dict(dct, error):
 
 
 class GetItem(BrowserView):
-
     def __call__(self):
 
         data = self.get_data()
@@ -45,10 +45,10 @@ class GetItem(BrowserView):
         ]
         for handler in sorted(handlers, key=lambda h: h.order):
             context_dict.update(handler())
-        if context_dict.get('_defaultpage'):
-            context_dict.update({
-                'default_page': context_dict.get('_defaultpage')
-            })
+        if context_dict.get("_defaultpage"):
+            context_dict.update(
+                {"default_page": context_dict.get("_defaultpage")}
+            )
         return context_dict
 
     def get_json_object(self, context_dict):
@@ -57,69 +57,71 @@ class GetItem(BrowserView):
             try:
                 JSON = json.dumps(context_dict)
                 passed = True
-            except Exception, error:
-                if 'serializable' in str(error):
+            except Exception as error:
+                if "serializable" in str(error):
                     key, context_dict = _clean_dict(context_dict, error)
                     logger.error(
-                        'Not serializable member {0} of {1} ignored'.format(
-                            key, repr(self)))
+                        "Not serializable member {0} of {1} ignored".format(
+                            key, repr(self)
+                        )
+                    )
                     passed = False
                 else:
-                    return ('ERROR: Unknown error serializing object: {0}'.format(
-                        str(error)))
+                    return "ERROR: Unknown error serializing object: {0}".format(
+                        str(error)
+                    )
 
-        self.request.response.setHeader('Content-Type', 'application/json')
+        self.request.response.setHeader("Content-Type", "application/json")
         return JSON
 
 
 class GetItemLink(GetItem):
-
     def get_data(self):
         """
         """
         data = super(GetItemLink, self).get_data()
-        if not data.get('title'):
-            data['title'] = data.get('id')
+        if not data.get("title"):
+            data["title"] = data.get("id")
         return data
 
 
 class GetItemEvent(GetItem):
-
     def get_data(self):
         """
         """
         data = super(GetItemEvent, self).get_data()
-        data.update({
-            'start': DateTime(data.get('startDate')).asdatetime().isoformat(),
-            'end': DateTime(data.get('endDate')).asdatetime().isoformat(),
-            'contact_name': data.get('contactName'),
-            'contact_email': data.get('contactEmail'),
-            'contact_phone': data.get('contactPhone'),
-            'event_url': data.get('eventUrl'),
-        })
-        data.pop('startDate', None)
-        data.pop('endDate', None)
-        data.pop('contactName', None)
-        data.pop('contactEmail', None)
-        data.pop('contactPhone', None)
-        data.pop('eventUrl', None)
+        data.update(
+            {
+                "start": DateTime(data.get("startDate"))
+                .asdatetime()
+                .isoformat(),
+                "end": DateTime(data.get("endDate")).asdatetime().isoformat(),
+                "contact_name": data.get("contactName"),
+                "contact_email": data.get("contactEmail"),
+                "contact_phone": data.get("contactPhone"),
+                "event_url": data.get("eventUrl"),
+            }
+        )
+        data.pop("startDate", None)
+        data.pop("endDate", None)
+        data.pop("contactName", None)
+        data.pop("contactEmail", None)
+        data.pop("contactPhone", None)
+        data.pop("eventUrl", None)
         return data
 
 
 class GetItemDocument(GetItem):
-
     def get_data(self):
         """
         """
         data = super(GetItemDocument, self).get_data()
-        data.update({
-            'table_of_contents': self.context.tableContents})
+        data.update({"table_of_contents": self.context.tableContents})
 
         return data
 
 
 class GetItemTopic(GetItem):
-
     def convert_criterion(self, old_criterion):
         pass
 
@@ -132,12 +134,14 @@ class GetItemTopic(GetItem):
         criterions_list = mt.__call__(self.context)
         # check format in case of date values
         for crit_dict in criterions_list:
-            values = crit_dict.get('v')
+            values = crit_dict.get("v")
             if not values:
                 continue
             if isinstance(values, int):
                 continue
-            if not any([True for x in values if isinstance(x, DateTime)]):  # noqa
+            if not any(
+                [True for x in values if isinstance(x, DateTime)]
+            ):  # noqa
                 continue
 
             new_values = []
@@ -146,74 +150,72 @@ class GetItemTopic(GetItem):
                 new_values.append(val.asdatetime().isoformat())
             if isinstance(values, tuple):
                 new_values = tuple(new_values)
-            crit_dict.update({'v': new_values})
+            crit_dict.update({"v": new_values})
 
         sort_on = mt._collection_sort_on
         sort_reversed = mt._collection_sort_reversed
 
-        data.update({'query': criterions_list})
-        data.update({'sort_on': sort_on})
-        data.update({'sort_reversed': sort_reversed})
+        data.update({"query": criterions_list})
+        data.update({"sort_on": sort_on})
+        data.update({"sort_reversed": sort_reversed})
 
-        if not data.get('itemCount'):
-            data.update({'item_count': '30'})
+        if not data.get("itemCount"):
+            data.update({"item_count": "30"})
         else:
-            data.update({
-                'item_count': data.get('itemCount')})
+            data.update({"item_count": data.get("itemCount")})
         return data
 
 
 class GetItemCollection(GetItem):
-
     def get_data(self):
         """
         """
         data = super(GetItemCollection, self).get_data()
-        query = data['query']
+        query = data["query"]
 
         fixed_query = []
         for el in query:
             tmp_dict = {}
             for key in el.keys():
-                if not isinstance(el[key], basestring):
+                if not isinstance(el[key], six.string_types):
                     tmp_lst = []
                     for item in el[key]:
-                        tmp_lst.append(unicode(item))
-                    tmp_dict.update({unicode(key): tmp_lst})
+                        tmp_lst.append(six.text_type(item))
+                    tmp_dict.update({six.text_type(key): tmp_lst})
                 else:
-                    tmp_dict.update({unicode(key): unicode(el[key])})
+                    tmp_dict.update(
+                        {six.text_type(key): six.text_type(el[key])}
+                    )
             fixed_query.append(tmp_dict)
 
-        data.update({'query': fixed_query})
-        data['item_count'] = data.get('limit', 30)
-        del data['limit']
+        data.update({"query": fixed_query})
+        data["item_count"] = data.get("limit", 30)
+        del data["limit"]
 
         return data
 
 
 class GetItemFile(GetItem):
-
     def get_data(self):
         """
         Files from Plone 3 could have title not set.
         In this case, set it with the id
         """
         data = super(GetItemFile, self).get_data()
-        if not data.get('title'):
-            data['title'] = data.get('id')
+        if not data.get("title"):
+            data["title"] = data.get("id")
         return data
 
 
 class GetItemImage(GetItem):
-
     def get_data(self):
         """
         Images from Plone 3 could have title not set.
         In this case, set it with the id
         """
         data = super(GetItemImage, self).get_data()
-        if not data.get('title'):
-            data['title'] = data.get('id')
+        if not data.get("title"):
+            data["title"] = data.get("id")
         return data
 
 
@@ -225,17 +227,19 @@ class GetCatalogResults(object):
     @property
     @memoize
     def query(self):
-        query = self.request.form.get('catalog_query', {})
+        query = self.request.form.get("catalog_query", {})
         if query:
             query = eval(base64.b64decode(query), {"__builtins__": None}, {})
-        query.update({'sort_on': 'getObjPositionInParent'})
+        query.update({"sort_on": "getObjPositionInParent"})
         return query
 
     @property
     @memoize
     def brains(self):
-        pc = api.portal.get_tool(name='portal_catalog')
-        return pc.unrestrictedSearchResults(**self.query)
+        pc = api.portal.get_tool(name="portal_catalog")
+        if api.env.plone_version() < "5.2":
+            return pc.unrestrictedSearchResults(**self.query)
+        return pc(**self.query)
 
     @property
     @memoize
@@ -250,15 +254,15 @@ class GetCatalogResults(object):
     def flatten(self, children):
         """ Recursively flatten the tree """
         for obj in children:
-            if obj['path']:
-                self.items.append(obj['path'])
+            if obj["path"]:
+                self.items.append(obj["path"])
 
-            children = obj.get('children', None)
+            children = obj.get("children", None)
             if children:
                 self.flatten(children)
 
     def pathInList(self, path):
-        path_str = '{}/'.format(path)
+        path_str = "{}/".format(path)
         for item_path in self.paths:
             if path_str in item_path:
                 return True
@@ -270,15 +274,19 @@ class GetCatalogResults(object):
 
         children = root.listFolderContents()
         for obj in children:
-            path = obj.absolute_url_path() if not getattr(obj, "getObject", None) else obj.getPath() # noqa
+            path = (
+                obj.absolute_url_path()
+                if not getattr(obj, "getObject", None)
+                else obj.getPath()
+            )  # noqa
             if obj.UID() not in self.uids:
                 if not self.pathInList(path):
                     # object is not in catalog results and isn't neither a
                     # folder in its tree
                     continue
-            obj_dict = {'path': path, 'children': []}
+            obj_dict = {"path": path, "children": []}
             if IFolderish.providedBy(obj):
-                obj_dict['children'] = self.explain_tree(obj)
+                obj_dict["children"] = self.explain_tree(obj)
 
             results.append(obj_dict)
 
@@ -287,22 +295,21 @@ class GetCatalogResults(object):
     def __call__(self):
 
         self.items = []
-        query = self.request.form.get('catalog_query', {})
+        query = self.request.form.get("catalog_query", {})
         if query:
             query = eval(base64.b64decode(query), {"__builtins__": None}, {})
-        query.update({'sort_on': 'getObjPositionInParent'})
+        query.update({"sort_on": "getObjPositionInParent"})
 
-        self.request.response.setHeader('Content-Type', 'application/json')
+        self.request.response.setHeader("Content-Type", "application/json")
 
         self.items = []
 
         root = api.portal.get()
+        tree = {"children": []}
+        tree["children"].extend(self.explain_tree(root))
 
-        tree = {'children': []}
-        tree['children'].extend(self.explain_tree(root))
-
-        if tree.get('path', None):
-            self.items.append(tree['path'])
-        self.flatten(tree['children'])
+        if tree.get("path", None):
+            self.items.append(tree["path"])
+        self.flatten(tree["children"])
         item_paths = self.items
         return json.dumps(item_paths)
